qx.Class.define("pf.UnitSelector",
{
    extend: pf.ui.SelectBox,
    
    members:
    {
        _dimension : null,
        
        update: function(dimension, def_units)
        {
            if (dimension == this._dimension) {
                return;
            }
            
            this._dimension = dimension;
            
            var list = this.getChildControl("list");
            
            // clear everything
            list.removeAll();

            var selected;
            var au_f;

            switch (dimension) {
            case "frequency":
                au_f = pf.base.Bohr.f0;
                           this.addNumItem("a.u.",  1.0);
                           this.addNumItem("Rad/s", 2*Math.PI*au_f);
                selected = this.addNumItem("Hz",    1.0*au_f);
                break;
            case "length":
                au_f = pf.base.Bohr.a0;
                           this.addNumItem("a.u.",    1.0);
                           this.addNumItem("&Aring;", 1.0e8*au_f, true);
                           this.addNumItem("nm",      1.0e7*au_f);
                           this.addNumItem("&mu;m",   1.0e4*au_f, true);
                selected = this.addNumItem("cm",      1.0*au_f);
                           this.addNumItem("m",       1.0e-2*au_f);
                break;
            case "area":
                au_f = Math.pow(pf.base.Bohr.a0, 2);
                           this.addNumItem("a.u.",           1.0);
                           this.addNumItem("Barn",           1.0e24*au_f);
                selected = this.addNumItem("cm<sup>2</sup>", 1.0*au_f, true);
                           this.addNumItem("m<sup>2</sup>",  1.0e-4*au_f, true);
                break;
            case "velocity":
                au_f = pf.base.Bohr.v0;
                           this.addNumItem("a.u.",     1.0);
                selected = this.addNumItem("cm/s",     1.0*au_f);
                           this.addNumItem("m/s",      1.0e-2*au_f);
                           this.addNumItem("cm/&mu;s", 1.0e-6*au_f, true);
                           this.addNumItem("v/c",      1.0/3e10*au_f);
                break;
            case "mass_density":
                au_f = pf.base.Bohr.m0*pf.base.Bohr.n0;
                           this.addNumItem("a.u.",             1.0);
                           this.addNumItem("kg/m<sup>3</sup>", 1.0e3*au_f, true);
                selected = this.addNumItem("g/cm<sup>3</sup>", 1.0*au_f, true);
                break;
            case "energy":
                au_f = pf.base.Bohr.E0;
                           this.addNumItem("a.u.",            1.0);
                           this.addNumItem("cm<sup>-1</sup>", 8065.5*au_f, true);
                selected = this.addNumItem("eV",              1.0*au_f);
                           this.addNumItem("erg",             1.6022e-12*au_f);
                           this.addNumItem("J",               1.6022e-19*au_f);
                break;
            case "pressure":
                au_f = pf.base.Bohr.P0;
                           this.addNumItem("a.u.",               1.0);
                selected = this.addNumItem("Dyn/cm<sup>2</sup>", 1.0*au_f, true);
                           this.addNumItem("Pa",                 0.1*au_f);
                           this.addNumItem("Torr",               7.5006e-4*au_f);
                           this.addNumItem("bar",                1.0e-6*au_f);
                           this.addNumItem("atm",                9.8692e-7*au_f);
                break;
            case "power_density":
                au_f = pf.base.Bohr.E0/pf.base.Bohr.V0/pf.base.Bohr.t0;
                           this.addNumItem("a.u.",                 1.0);
                           this.addNumItem("erg/cm<sup>3</sup>/s", 1.6022e-12*au_f, true);
                           this.addNumItem("W/m<sup>3</sup>",      1.6022e-13*au_f, true);
                selected = this.addNumItem("W/cm<sup>3</sup>",     1.6022e-19*au_f, true);
                break;
            case "spectral_power_density":
                au_f = 1.0/pf.base.Bohr.V0/pf.base.Bohr.t0;
                           this.addNumItem("a.u.",                    1.0);
                           this.addNumItem("erg/s/cm<sup>3</sup>/eV", 1.6022e-12*au_f, true);
                           this.addNumItem("W/m<sup>3</sup>/eV",      1.6022e-13*au_f, true);
                selected = this.addNumItem("W/cm<sup>3</sup>/eV",     1.6022e-19*au_f, true);
                           this.addNumItem("1/s/cm<sup>3</sup>",      1.0*au_f, true);
                break;
            case "efield":
                au_f = pf.base.Bohr.F0;
                           this.addNumItem("a.u.",     1.0);
                           this.addNumItem("V/m",      1.0e2*au_f);
                selected = this.addNumItem("V/cm",     1.0*au_f);
                           this.addNumItem("StatV/cm", 1.0/300*au_f);
                           this.addNumItem("MV/cm",    1.0e-6*au_f);
                break;
            case "none":
                selected = this.addNumItem("---", 1.0);
                break;
            default:
                selected = this.addNumItem("???", 1.0);
                break;
            }

            if (def_units) {
                var models = new Array(def_units);
                list.setModelSelection(models);
            } else
            if (selected) {
                var sels = Array(selected);
                list.setSelection(sels);
            }
        }
    }
});
